# Base Docker image

It is based on [`docker.io/fedora:25`](https://hub.docker.com/_/fedora/).

The only thing that is added are [Resolwe Runtime Utilities](
http://resolwe-runtime-utils.readthedocs.io).

It is used as the base image for all other Resolwe toolkit Docker images.
